function [ simMat ] = HeteSim(tranCell, path, beginId, endId)
%function [ simMat ] = PathConsSimRank()
%Calculate path-constrained similarity rank
%   transCell is the transition probility matrix cell. {transMat1, transMat2, ...}
%   tranType record the node type of transition probility matrix
%   path is a row vector. i means transCell[i]; -i means transCell[i]'
%   beginId is the id of beginning node. It is an optional parameter.
%   endId is the id of end node. It is an optional parameter.
%   simMat is the simliarity matrix. 

% load DBLP-DBIS-test;
% rMat1 = full(PA);
% rMat2 = full(PC);
% rMat3 = full(PT);
% tranCell = {rMat1,rMat2,rMat3};
% tranType = [1,2;1,3;1,4];
% path = [-2,3,-3,1];

len = length(path);

calIndex = path(1);
if(calIndex < 0)
    calMat = cell2mat(tranCell(1,round(abs(calIndex))))';
else
    calMat = cell2mat(tranCell(2,round(abs(calIndex))));
end
if nargin >= 4
    leftSimMat = calMat(beginId,:);
else
    leftSimMat = calMat;
end
clear calMat;


for i = 2 : 1 : floor(len/2)
    calIndex = path(i);
    if(calIndex < 0)
        calMat = cell2mat(tranCell(1,round(abs(calIndex))))';
    else
        calMat = cell2mat(tranCell(2,round(abs(calIndex))));
    end
    leftSimMat = leftSimMat*calMat;
    clear calMat;
end


calIndex = path(len);
if(calIndex < 0)
    calMat = cell2mat(tranCell(2,round(abs(calIndex))))';
else
    calMat = cell2mat(tranCell(1,round(abs(calIndex))));
end
if nargin >= 5
    rightSimMat = calMat(:,endId);
else
    rightSimMat = calMat;
end
clear calMat;

for j = len-1 : -1 : ceil(len/2)+1
    calIndex = path(j);
    if(calIndex < 0)
        calMat = cell2mat(tranCell(2,round(abs(calIndex))))';
    else
        calMat = cell2mat(tranCell(1,round(abs(calIndex))));
    end
    rightSimMat = calMat*rightSimMat;
    clear calMat;
end


%cal similarity matrix of middle node
if mod(len,2) ~= 0
    %odd number length
    midIndex = path(floor(len/2+1));
    if(midIndex<0)
        midMat = cell2mat(tranCell(1,-midIndex));
        midMat = midMat';
    else
        midMat = cell2mat(tranCell(1,midIndex));
    end
    %similarity of heter node. 
    [nodeEdgeMat, edgeNodeMat] = AdjMatDecopose(midMat);
    clear midMat;
    nodeEdgeMat = NormMatrix(nodeEdgeMat,0,2);
    edgeNodeMat = NormMatrix(edgeNodeMat,0,1);
    leftSimMat = leftSimMat*nodeEdgeMat;
    rightSimMat = edgeNodeMat*rightSimMat;
end
simMat = leftSimMat*rightSimMat;

% simMat = leftSimMat*rightSimMat;
% normLeft = sqrt(sum(leftSimMat.*leftSimMat,2));
% normRight = sqrt(sum(rightSimMat.*rightSimMat,1));
% normTerm = normLeft*normRight;
% clear normLeft normRight;
% %simMat = simMat./normTerm;
% %simMat(normTerm==0)=0;
% 
% 
% [ sr, sc, sv ] = find(simMat);
% %fprintf('sparse : %.4f\n', length(sv)/(size(simMat,1)*size(simMat,2)));
% 
% nv = normTerm(simMat>0);
% sv = sv ./ nv;
% sv(nv==0) = 0;
% 
% simMat = sparse(sr, sc, sv, size(simMat,1), size(simMat,2));

end